@@ -1343,6 +1343,30 @@
         );
     }
 
+    function ControlGroup(props, control, description) {
+        return m$1(
+            "span",
+            {class: ["control-group", props.class]},
+            control,
+            description
+        );
+    }
+    function Control(props, ...content) {
+        return m$1(
+            "span",
+            {class: ["control-group__control", props.class]},
+            ...content
+        );
+    }
+    function Description(props, ...content) {
+        return m$1(
+            "span",
+            {class: ["control-group__description", props.class]},
+            ...content
+        );
+    }
+    Object.assign(ControlGroup, {Control, Description});
+
     function evalMath(expression) {
         const rpnStack = [];
         const workingStack = [];
